set terminal pdfcairo dashed font "Palatino, 10" enhanced lw 1 dl 1 size 4,3.2
#set terminal pdfcairo dashed enhanced size 4.9,3.1
set style fill transparent solid 0.25 noborder
set macros

gr='rgbcolor "#aaaaaa"'
bl='rgbcolor "#444444"'
p ='rgbcolor "#cc33cc"'
g ='rgbcolor "#33cc33"'
dg='rgbcolor "#119911"'
b ='rgbcolor "#2277ff"'
y ='rgbcolor "#ffdd11"'
dy='rgbcolor "#ffbb11"'
r ='rgbcolor "#ff4433"'
re='rgbcolor "#ff4433"'
w ='rgbcolor "#ffffff"'
br='rgbcolor "#964B00"'
set style lines 11 lc @bl lw 1 dt 1
set style lines 12 lc @g  lw 1 dt 1
set style lines 13 lc @b  lw 1 dt 1
set style lines 14 lc @r  lw 1 dt 1
set style lines 15 lc @dy lw 1 dt 1

set style lines 21 lc @bl lw 1 dt 4
set style lines 22 lc @g  lw 1 dt 4
set style lines 23 lc @b  lw 1 dt 4
set style lines 24 lc @r  lw 1 dt 4
set style lines 25 lc @dy lw 1 dt 4

set style lines 31 lc @bl lw 1 dt "_"
set style lines 32 lc @g  lw 1 dt "_"
set style lines 33 lc @b  lw 1 dt "_"
set style lines 34 lc @r  lw 1 dt "_"
set style lines 35 lc @dy lw 1 dt "_"

set style lines 41 lc @bl lw 1 dt 2
set style lines 42 lc @g  lw 1 dt 2
set style lines 43 lc @b  lw 1 dt 2
set style lines 44 lc @r  lw 1 dt 2
set style lines 45 lc @dy lw 1 dt 2

set style lines 51 lc @bl lw 1 dt "._."
set style lines 52 lc @g  lw 1 dt "._."
set style lines 53 lc @b  lw 1 dt "._."
set style lines 54 lc @r  lw 1 dt "._."
set style lines 55 lc @dy lw 1 dt "._."

set style lines 10 lc 0 lw 1 dt 1
set style lines 20 lc 0 lw 1 dt 4
set style lines 30 lc 0 lw 1 dt "_"
set style lines 40 lc 0 lw 1 dt 2
set style lines 50 lc 0 lw 1 dt "._."

proc='ggH'
muRs='0.5'

set title 'Higgs production in gluon fusion at LHC 13 TeV, m_H = 125 GeV'

set output 'plots/'.proc.'_distributions_priorscan.pdf'
set xlabel '{/Symbol S} = cross section  [pb]'
set ylabel 'Probability distribution of the cross section: P({/Symbol S})'
set xrange [0:70]
set mxtics 5
set key top left Left reverse
set key maxrows 5

set label 1 '{/Symbol m}_F = m_H/2' at graph 0.8,0.87
set label 3 '{/Symbol m} = m_H/2'   at graph 0.8,0.8

file1 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_00.dat'
file2 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_0+.dat'
file3 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_0-.dat'
file4 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_+0.dat'
file5 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_-0.dat'

set yrange [0:*]
set label 2 'Geometric behaviour model' at graph 0.05,0.45
plot file1 u 1:2  ls  11 w l   title 'given LO', \
     ''    u 1:5  ls  12 w l   title 'given NLO', \
     ''    u 1:8  ls  13 w l   title 'given NNLO', \
     ''    u 1:11 ls  14 w l   title 'given N3LO', \
     file2 u 1:2  ls  21 w l notitle 'given LO', \
     ''    u 1:5  ls  22 w l notitle 'given NLO', \
     ''    u 1:8  ls  23 w l notitle 'given NNLO', \
     ''    u 1:11 ls  24 w l notitle 'given N3LO', \
     ''    u 1:14 ls  25 w l notitle 'given N4LO', \
     file3 u 1:2  ls  31 w l notitle 'given LO', \
     ''    u 1:5  ls  32 w l notitle 'given NLO', \
     ''    u 1:8  ls  33 w l notitle 'given NNLO', \
     ''    u 1:11 ls  34 w l notitle 'given N3LO', \
     ''    u 1:14 ls  35 w l notitle 'given N4LO', \
     file4 u 1:2  ls  41 w l notitle 'given LO', \
     ''    u 1:5  ls  42 w l notitle 'given NLO', \
     ''    u 1:8  ls  43 w l notitle 'given NNLO', \
     ''    u 1:11 ls  44 w l notitle 'given N3LO', \
     ''    u 1:14 ls  45 w l notitle 'given N4LO', \
     file5 u 1:2  ls  51 w l notitle 'given LO', \
     ''    u 1:5  ls  52 w l notitle 'given NLO', \
     ''    u 1:8  ls  53 w l notitle 'given NNLO', \
     ''    u 1:11 ls  54 w l notitle 'given N3LO', \
     ''    u 1:14 ls  55 w l notitle 'given N4LO', \
     ''    u 1:(0/0) ps 0 pt 1 lc @w w p title ' ', \
     ''    u 1:(0/0) ls  10 w l title 'ε = 0.1, ω = 1', \
     ''    u 1:(0/0) ls  20 w l title 'ε = 0.1, ω = 2', \
     ''    u 1:(0/0) ls  30 w l title 'ε = 0.1, ω = 0', \
     ''    u 1:(0/0) ls  40 w l title 'ε = 1, ω = 1', \
     ''    u 1:(0/0) ls  50 w l title 'ε = 0.01, ω = 1', \
#



file1 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_0.dat'
file2 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_+.dat'
file3 = 'output/'.proc.'_P_Sigma_np1_muR'.muRs.'_-.dat'
set key maxrows 4

set yrange [0:0.25]
set label 2 'Scale variation model' at graph 0.35,0.65
plot file1 u 1:3  ls  11 w l   title 'given LO', \
     ''    u 1:6  ls  12 w l   title 'given NLO', \
     ''    u 1:9  ls  13 w l   title 'given NNLO    ', \
     ''    u 1:12 ls  14 w l   title 'given N3LO', \
     file2 u 1:3  ls  21 w l notitle 'given LO', \
     ''    u 1:6  ls  22 w l notitle 'given NLO', \
     ''    u 1:9  ls  23 w l notitle 'given NNLO', \
     ''    u 1:12 ls  24 w l notitle 'given N3LO', \
     file3 u 1:3  ls  31 w l notitle 'given LO', \
     ''    u 1:6  ls  32 w l notitle 'given NLO', \
     ''    u 1:9  ls  33 w l notitle 'given NNLO', \
     ''    u 1:12 ls  34 w l notitle 'given N3LO', \
     ''    u 1:(0/0) ls  10 w l title 'λ = 1', \
     ''    u 1:(0/0) ls  20 w l title 'λ = 2', \
     ''    u 1:(0/0) ls  30 w l title 'λ = 0', \
#


quit
